@@ -27,14 +27,17 @@ class Recipe(object):
         arguments = [x.strip()
                      for x in options.get('arguments', '').split()
                      if x.strip()]
+        env = [x.strip()
+               for x in options.get('environment', '').split()
+               if x.strip()]
         scr = options['cmd']
 
         return easy_install.scripts(
-            [(self.name, options['recipe']+'.ctl', 'run')],
+            [(self.name, options['recipe'] + '.ctl', 'run')],
             ws,
             options['executable'],
             options['bin-directory'],
-            arguments = [scr, arguments],
+            arguments=[scr, arguments, env],
             )
 
     def update(self):
